pub fn extract_docs(node: &SyntaxNode) -> Option<String>Expand description
Extract doc lines from /// or /** ... */. We do NOT gather #[doc="..."] attributes here.
Those can be handled separately if you want to unify them.
pub fn extract_docs(node: &SyntaxNode) -> Option<String>Extract doc lines from /// or /** ... */. We do NOT gather #[doc="..."] attributes here.
Those can be handled separately if you want to unify them.